unit GroupEditForm;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, Buttons, SearchObject, JvGroupBox;

type
  TFormGroupEdit = class(TForm)
    Label1: TLabel;
    ComboBoxGroup: TComboBox;
    CheckBoxRecurse: TCheckBox;
    BitBtnClose: TBitBtn;
    GroupBoxMask: TJvGroupBox;
    Label2: TLabel;
    SpeedButtonAdd: TSpeedButton;
    ComboBoxMasques: TComboBox;
    ListBoxMask: TListBox;
    ButtonSuppr: TButton;
    ButtonNouveau: TButton;
    ButtonRename: TButton;
    procedure ComboBoxGroupChange(Sender: TObject);
    procedure ComboBoxMasquesKeyPress(Sender: TObject; var Key: Char);
    procedure SpeedButtonAddClick(Sender: TObject);
    procedure ButtonSupprClick(Sender: TObject);
    procedure ListBoxMaskKeyUp(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure ListBoxMaskSelect(Sender: TObject);
    procedure CheckBoxRecurseClick(Sender: TObject);
    procedure ComboBoxGroupKeyPress(Sender: TObject; var Key: Char);
    procedure ButtonNouveauClick(Sender: TObject);
    procedure ButtonRenameClick(Sender: TObject);
  private
    { Dclarations prives }
    FList: TGroupList;
    FGrp: TGroup;
  public
    { Dclarations publiques }
    procedure Reset(const Index: Integer = 0);
  end;

var
  FormGroupEdit: TFormGroupEdit;

procedure EditGroupes(List: TGroupList; const Index: Integer = 0);

implementation

{$R *.dfm}

procedure EditGroupes(List: TGroupList; const Index: Integer = 0);
var I: Integer;
begin
  FormGroupEdit := TFormGroupEdit.Create(Application);
  with FormGroupEdit do try
    FList := List;

    Reset(Index);

    ShowModal;
    for I := FList.Count - 1 downto 0 do
      if TGroup(FList[I]).Mask.Count = 0 then
        FList.Delete(I);
  finally
    Free;
  end;
end;

procedure TFormGroupEdit.ComboBoxGroupChange(Sender: TObject);
begin
  if ComboBoxGroup.ItemIndex <> - 1 then begin
    FGrp := TGroup(FList.Items[ComboBoxGroup.ItemIndex]);
    CheckBoxRecurse.Checked := FGrp.Recurse;

    ListBoxMask.Clear;
    ListBoxMask.Items.AddStrings(FGrp.Mask);

    if FGrp = FList.DefaultGroup then begin
      CheckBoxRecurse.Enabled := false;
      GroupBoxMask.Enabled := false;
    end else begin
      CheckBoxRecurse.Enabled := true;
      GroupBoxMask.Enabled := true;
    end;
  end;

  if ComboBoxGroup.Text <> '' then begin
    ButtonRename.Enabled := FGrp <> nil;
    ButtonNouveau.Enabled := True;
  end else begin
    ButtonNouveau.Enabled := False;
    ButtonRename.Enabled := False;
  end;
end;

procedure TFormGroupEdit.ComboBoxMasquesKeyPress(Sender: TObject;
  var Key: Char);
begin
  if Key = #13 then begin
    SpeedButtonAdd.Click;
    Key := #0;
  end;
end;

procedure TFormGroupEdit.SpeedButtonAddClick(Sender: TObject);
begin
  if ComboBoxMasques.Text <> '' then begin
    FGrp.Mask.Add(ComboBoxMasques.Text);
    ComboBoxMasques.Text := '';
    ComboBoxGroupChange(Sender);
  end;
end;

procedure TFormGroupEdit.ButtonSupprClick(Sender: TObject);
var I: Integer;
begin
  for I := ListBoxMask.Count - 1 downto 0 do begin
    if ListBoxMask.Selected[I] then
      FGrp.Mask.Delete(I);
  end;
  ComboBoxGroupChange(Sender);
end;

procedure TFormGroupEdit.ListBoxMaskKeyUp(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  ButtonSuppr.Enabled := ListBoxMask.SelCount > 0;
  if Key = VK_DELETE then
    ButtonSuppr.Click;
end;

procedure TFormGroupEdit.ListBoxMaskSelect(Sender: TObject);
begin
  ButtonSuppr.Enabled := ListBoxMask.SelCount > 0;
end;

procedure TFormGroupEdit.CheckBoxRecurseClick(Sender: TObject);
begin
  FGrp.Recurse := CheckBoxRecurse.Checked;
end;

procedure TFormGroupEdit.ComboBoxGroupKeyPress(Sender: TObject;
  var Key: Char);
begin
  if Key = #13 then begin
    ButtonNouveau.Click;

    Key := #0;
  end;
end;

procedure TFormGroupEdit.Reset(const Index: Integer = 0);
var I: Integer;
    Lst: TStringList;
begin
  Lst := TStringList.Create;
  try
    Lst.Duplicates := dupIgnore;
    Lst.Sorted     := True;

    ComboBoxGroup.Items.BeginUpdate;
    try
      ComboBoxGroup.Clear;
      for I := 0 to FList.Count - 1 do begin
        ComboBoxGroup.Items.Add(TGroup(FList.Items[I]).Name);
        Lst.AddStrings(TGroup(FList.Items[I]).Mask);
      end;
      ComboBoxGroup.ItemIndex := Index;
      ComboBoxGroupChange(nil);
    finally
      ComboBoxGroup.Items.EndUpdate;
    end;

    ComboBoxMasques.Clear;
    ComboBoxMasques.Items.AddStrings(Lst);
  finally
    Lst.Free;
  end;
end;

procedure TFormGroupEdit.ButtonNouveauClick(Sender: TObject);
begin
  FGrp := TGroup.Create(ComboBoxGroup.Text);
  FList.Add(FGrp);
  Reset(FList.IndexOf(FGrp.CRC));
end;

procedure TFormGroupEdit.ButtonRenameClick(Sender: TObject);
begin
  FGrp.Name := ComboBoxGroup.Text;
  Reset(FList.IndexOf(FGrp.CRC));
end;

end.
