unit OptionsForm;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, Buttons, ComCtrls, ImgList, JvComponent, JvOLBar,
  JvGradientCaption, ExtCtrls, DeleteFrame, JvGroupBox, CheckLst, BrowseDr,
  SearchObject, Menus, OptionsManager;

type
  TFormOptions = class(TForm)
    BarControl: TJvOutlookBar;
    ImageListOptions: TImageList;
    PageControlOption: TPageControl;
    TabSheetForm: TTabSheet;
    TabSheetLog: TTabSheet;
    TabSheetPlugin: TTabSheet;
    TabSheetSearch: TTabSheet;
    TabSheetDebuggage: TTabSheet;
    BitBtnCancel: TBitBtn;
    BitBtnOK: TBitBtn;
    Label1: TLabel;
    Label2: TLabel;
    GradientCaption: TJvGradientCaption;
    TreeViewSearch: TTreeView;
    Label3: TLabel;
    Label4: TLabel;
    BitBtnAdd: TBitBtn;
    BitBtnDelete: TBitBtn;
    Bevel1: TBevel;
    LabelOptions: TLabel;
    CheckBoxDebug: TCheckBox;
    CheckBoxSearch: TCheckBox;
    TabSheetSearchOptions: TTabSheet;
    AskOptionOrdinary: TAskOptionFrame;
    AskOptionArchive: TAskOptionFrame;
    AskOptionReadOnly: TAskOptionFrame;
    AskOptionHidden: TAskOptionFrame;
    AskOptionSystem: TAskOptionFrame;
    CheckBoxDetail: TCheckBox;
    CheckBoxMinimize: TCheckBox;
    CheckBoxTrayIcon: TCheckBox;
    CheckBoxLog: TCheckBox;
    GroupBoxLog: TJvGroupBox;
    Label5: TLabel;
    ButtonBrownsLog: TSpeedButton;
    LabelDirLog: TStaticText;
    GroupBoxEvent: TJvGroupBox;
    CheckBoxTime: TCheckBox;
    CheckBoxSize: TCheckBox;
    CheckBoxStandard: TCheckBox;
    CheckBoxDeletedFile: TCheckBox;
    CheckBoxWarning: TCheckBox;
    CheckBoxError: TCheckBox;
    GroupBoxDebug: TJvGroupBox;
    CheckBoxDebugTestMode: TCheckBox;
    CheckBoxDebugStandard: TCheckBox;
    GroupBoxSearch: TJvGroupBox;
    CheckBoxResetLog: TCheckBox;
    RichEditLog: TRichEdit;
    ButtonClearLog: TButton;
    LabelLogSize: TLabel;
    CheckListBoxPlugins: TCheckListBox;
    ImageListDrive: TImageList;
    CheckBoxLogPlus: TCheckBox;
    BitBtnApply: TBitBtn;
    BrowseLog: TBrowseDirectoryDlg;
    ComboBoxGroups: TComboBox;
    SpeedButtonInsert: TSpeedButton;
    ButtonEditGroup: TButton;
    Bevel2: TBevel;
    BrowseDir: TBrowseDirectoryDlg;
    procedure BarControlButtonClick(Sender: TObject; Index: Integer);
    procedure FormCreate(Sender: TObject);
    procedure CheckBoxLogClick(Sender: TObject);
    procedure CheckBoxSearchClick(Sender: TObject);
    procedure CheckBoxDebugClick(Sender: TObject);
    procedure CheckBoxMinimizeClick(Sender: TObject);
    procedure ButtonClearLogClick(Sender: TObject);
    procedure CheckBoxDetailClick(Sender: TObject);
    procedure CheckBoxTrayIconClick(Sender: TObject);
    procedure CheckBoxTimeClick(Sender: TObject);
    procedure CheckBoxSizeClick(Sender: TObject);
    procedure CheckBoxStandardClick(Sender: TObject);
    procedure CheckBoxDeletedFileClick(Sender: TObject);
    procedure CheckBoxWarningClick(Sender: TObject);
    procedure CheckBoxErrorClick(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure CheckBoxResetLogClick(Sender: TObject);
    procedure CheckBoxDebugStandardClick(Sender: TObject);
    procedure CheckBoxDebugTestModeClick(Sender: TObject);
    procedure CheckBoxLogPlusClick(Sender: TObject);
    procedure BitBtnCancelClick(Sender: TObject);
    procedure BitBtnOKClick(Sender: TObject);
    procedure BitBtnApplyClick(Sender: TObject);
    procedure AskOptionOrdinaryChange(Sender: TObject);
    procedure AskOptionArchiveChange(Sender: TObject);
    procedure AskOptionReadOnlyChange(Sender: TObject);
    procedure AskOptionHiddenChange(Sender: TObject);
    procedure AskOptionSystemChange(Sender: TObject);
    procedure ButtonBrownsLogClick(Sender: TObject);
    procedure CheckListBoxPluginsClickCheck(Sender: TObject);
    procedure CheckListBoxPluginsMouseMove(Sender: TObject;
      Shift: TShiftState; X, Y: Integer);
    procedure TreeViewSearchChange(Sender: TObject; Node: TTreeNode);
    procedure ButtonEditGroupClick(Sender: TObject);
    procedure BitBtnAddClick(Sender: TObject);
    procedure SpeedButtonInsertClick(Sender: TObject);
    procedure BitBtnDeleteClick(Sender: TObject);
  private
    FOldItem: Integer;
    FLogFileName: string;

    FDir: TDirectory;

    FTreeSearch: TDrives;
    FGroupList : TGroupList;
    procedure SetLogFileName(const Value: string);
    function GetOptions: TOptionsManager;
  private
    { Dclarations prives }
    procedure OnOptionsChange(Sender: TObject);

    procedure LoadPlugins;
    procedure LoadOptions;
    procedure LoadTree;

    function PathSelected(Node: TTreeNode): string;
    procedure PathSelect(Value: String);

    property LogFileName: string read FLogFileName write SetLogFileName;
    property OptionsMgr: TOptionsManager read GetOptions;
  public
    { Dclarations publiques }
  end;

var
  FormOptions: TFormOptions = nil;

implementation

uses PluginsManager, PluginsTypes, FileTools, PaintUtils,
  LogManager, GroupEditForm, SearchForm, resources;

{$R *.dfm}

var CheckListBoxPluginsHint: string;

procedure TFormOptions.BarControlButtonClick(Sender: TObject;
  Index: Integer);
begin
  PageControlOption.ActivePageIndex := BarControl.ActivePage.Buttons[Index].Tag;
  GradientCaption.LabelCaption := BarControl.ActivePage.Buttons[Index].Caption;
end;

procedure TFormOptions.FormCreate(Sender: TObject);
begin
  OptionsMgr.LogManager.Detach;
  OptionsMgr.OnChange := OnOptionsChange;

  BarControl.ActivePageIndex := 0;
  BarControlButtonClick(BarControl, 0);

  AskOptionOrdinary.OnChange := AskOptionOrdinaryChange;
  AskOptionArchive.OnChange := AskOptionArchiveChange;
  AskOptionReadOnly.OnChange := AskOptionReadOnlyChange;
  AskOptionHidden.OnChange := AskOptionHiddenChange;
  AskOptionSystem.OnChange := AskOptionSystemChange;

  CheckListBoxPluginsHint := CheckListBoxPlugins.Hint;
  FOldItem := -1;

  FGroupList  := TGroupList.Create;
  FGroupList.OnChange := OnOptionsChange;
  OptionsMgr.PersonalSearch.GroupList.CopyTo(FGroupList);
  FTreeSearch := TDrives.Create(FGroupList);
  OptionsMgr.PersonalSearch.DriveList.CopyTo(FTreeSearch);

  LoadPlugins;
  LoadOptions;
  LoadTree;
end;

procedure TFormOptions.CheckBoxLogClick(Sender: TObject);
begin
  GroupBoxLog.Enabled := CheckBoxLog.Checked;
  OptionsMgr.LogActive := CheckBoxLog.Checked;
end;

procedure TFormOptions.CheckBoxSearchClick(Sender: TObject);
var I: Integer;
begin
  GroupBoxSearch.Enabled := CheckBoxSearch.Checked;
  for I := 0 to TabSheetSearchOptions.ControlCount - 1 do
    (TabSheetSearchOptions.Controls[I] as TFrame).Enabled := CheckBoxSearch.Checked;
  OptionsMgr.PersonalSearchActive := CheckBoxSearch.Checked;
end;

procedure TFormOptions.CheckBoxDebugClick(Sender: TObject);
begin
  GroupBoxDebug.Enabled := CheckBoxDebug.Checked;
  OptionsMgr.Debug := CheckBoxDebug.Checked;
end;

procedure TFormOptions.CheckBoxMinimizeClick(Sender: TObject);
begin
  CheckBoxTrayIcon.Enabled := CheckBoxMinimize.Checked;
  OptionsMgr.GlobalMinimize := CheckBoxMinimize.Checked;
end;

procedure TFormOptions.LoadPlugins;
var I, Prev, Header, Idx: Integer;
begin
  Prev := -1;
  for I := 0 to OptionsMgr.PluginsList.Count - 1 do begin

    if Prev <> Ord(OptionsMgr.PluginsList.Items[I].pLibType) then begin
      Prev := Ord(OptionsMgr.PluginsList.Items[I].pLibType);
      case OptionsMgr.PluginsList.Items[I].pLibType of
        pltSystem: Header := CheckListBoxPlugins.Items.Add(rsHeaderPluginsSystem);
        pltUser  : Header := CheckListBoxPlugins.Items.Add(rsHeaderPluginsUser);
        pltIE    : Header := CheckListBoxPlugins.Items.Add(rsHeaderPluginsBrowser);
        pltOther : Header := CheckListBoxPlugins.Items.Add(rsHeaderPluginsOther);
        else
          Header := 0;
      end;
      CheckListBoxPlugins.Header[Header] := True;
    end;

    Idx := CheckListBoxPlugins.Items.Add(OptionsMgr.PluginsList.Items[I].pDescription);
    CheckListBoxPlugins.Checked[Idx] := OptionsMgr.NettoyageStd.IndexOf(OptionsMgr.PluginsList.Items[I].pIdentificateur) <> -1;
  end;
end;

procedure TFormOptions.LoadOptions;
begin
  CheckBoxDetail.Checked := OptionsMgr.Global.Details;
  CheckBoxMinimize.Checked := OptionsMgr.Global.Minimize;
  CheckBoxTrayIcon.Checked := OptionsMgr.Global.TrayIcon;

  CheckBoxLog.Checked := OptionsMgr.Log.Active;
  LogFileName := OptionsMgr.Log.Directory;
  CheckBoxTime.Checked := leTimeSearch in OptionsMgr.Log.Events;
  CheckBoxSize.Checked := leSizeFree in OptionsMgr.Log.Events;
  CheckBoxDeletedFile.Checked := leDeletedFile in OptionsMgr.Log.Events;
  CheckBoxWarning.Checked := leWarning in OptionsMgr.Log.Events;
  CheckBoxError.Checked := leError in OptionsMgr.Log.Events;
  CheckBoxStandard.Checked := leStdClean in OptionsMgr.Log.Events;
  CheckBoxResetLog.Checked := OptionsMgr.Log.EraseOldFile;

  CheckBoxSearch.Checked := OptionsMgr.PersonalSearch.Active;
  AskOptionOrdinary.SetValues(OptionsMgr.PersonalSearch.OrdinaryFiles);
  AskOptionArchive.SetValues(OptionsMgr.PersonalSearch.ArchivedFiles);
  AskOptionReadOnly.SetValues(OptionsMgr.PersonalSearch.ReadOnlyFiles);
  AskOptionHidden.SetValues(OptionsMgr.PersonalSearch.HiddenFiles);
  AskOptionSystem.SetValues(OptionsMgr.PersonalSearch.SystemsFiles);

  CheckBoxDebug.Checked := OptionsMgr.Debug;
  CheckBoxDebugStandard.Checked := OptionsMgr.DebugOptions.NoStandard;
  CheckBoxDebugTestMode.Checked := OptionsMgr.DebugOptions.NoDelete;
  CheckBoxLogPlus.Checked := OptionsMgr.DebugOptions.DetailsLog;
end;

procedure TFormOptions.SetLogFileName(const Value: string);
var MaxSize: Integer;
    FileName: string;
begin
  if FLogFileName <> Value then begin
    MaxSize := Round(LabelDirLog.Width / (Canvas.TextWidth(Value) / Length(Value)));
    LabelDirLog.Caption := MinimizeFileName(Value, MaxSize);

    FileName := IncludeTrailingPathDelimiter(Value) + cstLogFileName;
    if FileExists(FileName) then begin
      RichEditLog.Enabled := true;
      RichEditLog.Lines.LoadFromFile(FileName);
      LabelLogSize.Caption := Format(rsLogSize, [SizeToStr(SizeOfFile(FileName))]);
    end else begin
      RichEditLog.Lines.Clear;
      RichEditLog.Enabled := false;
      LabelLogSize.Caption := '';
      ButtonClearLog.Enabled := False;
    end;

    FLogFileName := Value;
    OptionsMgr.LogDirectory := Value;
  end;
end;

procedure TFormOptions.ButtonClearLogClick(Sender: TObject);
begin
  DeleteFile(IncludeTrailingPathDelimiter(LogFileName) + cstLogFileName);

  RichEditLog.Lines.Clear;
  RichEditLog.Enabled := false;
  LabelLogSize.Caption := '';
  ButtonClearLog.Enabled := False;
end;

procedure TFormOptions.CheckBoxDetailClick(Sender: TObject);
begin
  OptionsMgr.GlobalDetails := CheckBoxDetail.Checked;
end;

procedure TFormOptions.CheckBoxTrayIconClick(Sender: TObject);
begin
  OptionsMgr.GlobalTrayIcon := CheckBoxTrayIcon.Checked;
end;

procedure TFormOptions.CheckBoxTimeClick(Sender: TObject);
begin
  if CheckBoxTime.Checked then
    OptionsMgr.LogEvents := OptionsMgr.LogEvents + [leTimeSearch]
  else
    OptionsMgr.LogEvents := OptionsMgr.LogEvents - [leTimeSearch]
end;

procedure TFormOptions.CheckBoxSizeClick(Sender: TObject);
begin
  if CheckBoxSize.Checked then
    OptionsMgr.LogEvents := OptionsMgr.LogEvents + [leSizeFree]
  else
    OptionsMgr.LogEvents := OptionsMgr.LogEvents - [leSizeFree]
end;

procedure TFormOptions.CheckBoxStandardClick(Sender: TObject);
begin
  if CheckBoxStandard.Checked then
    OptionsMgr.LogEvents := OptionsMgr.LogEvents + [leStdClean]
  else
    OptionsMgr.LogEvents := OptionsMgr.LogEvents - [leStdClean]
end;

procedure TFormOptions.CheckBoxDeletedFileClick(Sender: TObject);
begin
  if CheckBoxDeletedFile.Checked then
    OptionsMgr.LogEvents := OptionsMgr.LogEvents + [leDeletedFile]
  else
    OptionsMgr.LogEvents := OptionsMgr.LogEvents - [leDeletedFile]
end;

procedure TFormOptions.CheckBoxWarningClick(Sender: TObject);
begin
  if CheckBoxWarning.Checked then
    OptionsMgr.LogEvents := OptionsMgr.LogEvents + [leWarning]
  else
    OptionsMgr.LogEvents := OptionsMgr.LogEvents - [leWarning]
end;

procedure TFormOptions.CheckBoxErrorClick(Sender: TObject);
begin
  if CheckBoxError.Checked then
    OptionsMgr.LogEvents := OptionsMgr.LogEvents + [leError]
  else
    OptionsMgr.LogEvents := OptionsMgr.LogEvents - [leError]
end;

procedure TFormOptions.OnOptionsChange(Sender: TObject);
begin
  if OptionsMgr.Modified then begin
    BitBtnApply.Visible := True;
    BitBtnOK.Visible := True;
    BitBtnCancel.Kind := bkCancel;
  end else begin
    BitBtnApply.Visible := False;
    BitBtnOK.Visible := False;
    BitBtnCancel.Kind := bkClose;
  end;
end;

procedure TFormOptions.FormDestroy(Sender: TObject);
begin
  OptionsMgr.OnChange := nil;
  FTreeSearch.Free;
  FGroupList.Free;
end;

procedure TFormOptions.CheckBoxResetLogClick(Sender: TObject);
begin
  OptionsMgr.LogEraseOldFile := CheckBoxResetLog.Checked;
end;

procedure TFormOptions.CheckBoxDebugStandardClick(Sender: TObject);
begin
  OptionsMgr.DebugNoStandard := CheckBoxDebugStandard.Checked;
end;

procedure TFormOptions.CheckBoxDebugTestModeClick(Sender: TObject);
begin
  OptionsMgr.DebugNoDelete := CheckBoxDebugTestMode.Checked;
end;

procedure TFormOptions.CheckBoxLogPlusClick(Sender: TObject);
begin
  OptionsMgr.DebugDetailsLog := CheckBoxLogPlus.Checked;
end;

procedure TFormOptions.BitBtnCancelClick(Sender: TObject);
begin
  OptionsMgr.LoadFromRegistry;
end;

procedure TFormOptions.BitBtnOKClick(Sender: TObject);
begin
  BitBtnApplyClick(Self);
end;

procedure TFormOptions.BitBtnApplyClick(Sender: TObject);
begin
  FGroupList.CopyTo(OptionsMgr.PersonalSearch.GroupList);
  FTreeSearch.CopyTo(OptionsMgr.PersonalSearch.DriveList);
  OptionsMgr.SaveToRegistry;
end;

procedure TFormOptions.AskOptionOrdinaryChange(Sender: TObject);
begin
  OptionsMgr.PersonalSearchOrdinaryFiles := AskOptionOrdinary.GetValues;
end;

procedure TFormOptions.AskOptionArchiveChange(Sender: TObject);
begin
  OptionsMgr.PersonalSearchArchivedFiles := AskOptionArchive.GetValues;
end;

procedure TFormOptions.AskOptionReadOnlyChange(Sender: TObject);
begin
  OptionsMgr.PersonalSearchReadOnlyFiles := AskOptionReadOnly.GetValues;
end;

procedure TFormOptions.AskOptionHiddenChange(Sender: TObject);
begin
  OptionsMgr.PersonalSearchHiddenFiles := AskOptionHidden.GetValues;
end;

procedure TFormOptions.AskOptionSystemChange(Sender: TObject);
begin
  OptionsMgr.PersonalSearchSystemsFiles := AskOptionSystem.GetValues;
end;

procedure TFormOptions.ButtonBrownsLogClick(Sender: TObject);
begin
  BrowseLog.Selection := LogFileName;
  if BrowseLog.Execute then begin
    LogFileName := BrowseLog.Selection;
  end;
end;

procedure TFormOptions.CheckListBoxPluginsClickCheck(Sender: TObject);
var I, K: Integer;
begin
  K := 0; OptionsMgr.NettoyageStd.Clear;
  for I := 0 to CheckListBoxPlugins.Items.Count - 1 do
    if not CheckListBoxPlugins.Header[I] then begin
      if CheckListBoxPlugins.Checked[I] then
        OptionsMgr.NettoyageStd.Add(OptionsMgr.PluginsList.Items[K].pIdentificateur);
      Inc(K);
    end;
end;

procedure TFormOptions.CheckListBoxPluginsMouseMove(Sender: TObject;
  Shift: TShiftState; X, Y: Integer);
var Item, I, J, Size: Integer;
    Line            : String;
    Directory       : PChar;
begin
  Item := CheckListBoxPlugins.ItemAtPos(Point(X, Y), True);
  if Item <> FOldItem then begin
    Application.CancelHint;
    if (Item <> -1) and (not CheckListBoxPlugins.Header[Item]) then begin
      J := -1;
      for I := 0 to Item do
        if not CheckListBoxPlugins.Header[I] then
          Inc(J);

      Line := OptionsMgr.PluginsList.Items[J].pDescription + #10#13;
      if Assigned(OptionsMgr.PluginsList.Items[J].pDirectoryFunc) then begin
        OptionsMgr.PluginsList.Items[J].pDirectoryFunc(Directory, Size);
        Line := Line + Format(rsPluginsInfos,
                              [String(Directory), SizeToStr(Size)]);
      end;


      CheckListBoxPlugins.Hint := Line;
    end else
      CheckListBoxPlugins.Hint := CheckListBoxPluginsHint;
    Application.ActivateHint(Point(X, Y));
    FOldItem := Item;
  end;
end;

procedure TFormOptions.TreeViewSearchChange(Sender: TObject;
  Node: TTreeNode);
var I   : Integer;
begin
  ComboBoxGroups.Enabled := false;
  SpeedButtonInsert.Enabled := false;
  ComboBoxGroups.Items.Clear;
  LabelOptions.Caption := '';
  FDir := nil;
  BitBtnDelete.Enabled := (TreeViewSearch.Selected <> nil) and
                          (TreeViewSearch.Selected.Level > 0) and
                          (TreeViewSearch.Selected.ImageIndex in [5, 7, 9]);

  if Assigned(Node) then begin
    case Node.ImageIndex of
      9,
      1..5 : begin // Nous avons un dossier ou un lecteur
        FDir := FTreeSearch.Browse(PathSelected(Node));

        for I := 0 to FGroupList.Count - 1 do begin
          if FDir.IndexOf(TGroup(FGroupList.Items[I]).CRC) = -1 then
            ComboBoxGroups.Items.Add(TGroup(FGroupList.Items[I]).Name);
        end;

        ComboBoxGroups.ItemIndex := 0;
        ComboBoxGroups.Enabled := true;
        SpeedButtonInsert.Enabled := true;
      end;
      7    : begin // C'est un groupe
        ComboBoxGroups.Items.Add(Node.Text);
        ComboBoxGroups.ItemIndex := 0;
        if TGroup(FGroupList[FGroupList.IndexOf(Node.Text)]).Recurse then
          LabelOptions.Caption := Format(rsOptionsStr, ['X'])
        else
          LabelOptions.Caption := Format(rsOptionsStr, ['  '])
      end;
      8    : begin // Le parent est un group
        ComboBoxGroups.Items.Add(Node.Parent.Text);
        ComboBoxGroups.ItemIndex := 0;
        if TGroup(FGroupList[FGroupList.IndexOf(Node.Parent.Text)]).Recurse then
          LabelOptions.Caption := Format(rsOptionsStr, ['X'])
        else
          LabelOptions.Caption := Format(rsOptionsStr, ['  '])
      end;
      else ;   // Cas inconnue, Autre
    end;
  end;
end;

procedure TFormOptions.ButtonEditGroupClick(Sender: TObject);
var Backup: TMemoryStream;
begin
  Backup := TMemoryStream.Create;
  try
    FTreeSearch.SaveToStream(Backup);
    Backup.Position := 0;
    EditGroupes(FGroupList);
    FTreeSearch.LoadFromStream(Backup);
  finally
    Backup.Free;
  end;
  LoadTree;
end;

procedure TFormOptions.LoadTree;
begin
  TreeViewSearch.Items.BeginUpdate;
  try
    TreeViewSearch.Items.Clear;
    FTreeSearch.GenerateTreeNode(TreeViewSearch.Items);
    TreeViewSearchChange(nil, nil);
  finally
    TreeViewSearch.Items.EndUpdate;
  end;
end;

procedure TFormOptions.BitBtnAddClick(Sender: TObject);
begin
  if BrowseDir.Execute then begin
    FTreeSearch.AddPath(BrowseDir.Selection);
    LoadTree;
    PathSelect(BrowseDir.Selection);
    OptionsMgr.Modify;
  end;
end;

procedure TFormOptions.SpeedButtonInsertClick(Sender: TObject);
var Index: Integer;
    Dossier: String;
begin
  if FDir <> nil then begin
    Dossier := FDir.Path;
    Index := FGroupList.IndexOf(ComboBoxGroups.Text);
    if Index <> -1 then begin
      FDir.Groups.Add(FGroupList[Index]);

      LoadTree;
      PathSelect(Dossier);
      OptionsMgr.Modify;
    end;
  end;
end;

function TFormOptions.PathSelected(Node: TTreeNode): string;
var P   : TTreeNode;
    Path: String;
begin
  P := Node; Path := '';

  while P.ImageIndex in [6..8] do P := P.Parent;

  while P.ImageIndex in [5, 9] do begin
    Path := P.Text + '\' + Path;
    P := P.Parent;
  end;
  Path := P.Text + ':\' + Path;
  result := Path;
end;

procedure TFormOptions.PathSelect(Value: String);
var P      : TTreeNode;
    Dossier: String;
    I      : Integer;
    Stop   : boolean;
begin
  P := nil;

  Value := IncludeTrailingPathDelimiter(Value);

  Dossier := Copy(Value, 1, Pos(':\', Value) - 1) ;
  Delete(Value, 1, Pos(':\', Value) + 1);

  // Recherche du lecteur
  Stop := False;
  for I := 0 to TreeViewSearch.Items.Count - 1 do begin
    if(AnsiCompareText(TreeViewSearch.Items.Item[I].Text, Dossier) = 0) then begin
      P := TreeViewSearch.Items.Item[I];
      Stop := True;
      Break;
    end;
  end;

  if Stop then begin
    P.Expand(False);
    Dossier := Copy(Value, 1, Pos('\', Value) - 1);
    Delete(Value, 1, Pos('\', Value));

    while Dossier <> '' do begin
      // Recherche du dossier
      Stop := False;
      for I := 0 to P.Count - 1 do begin
        if(AnsiCompareText(P.Item[I].Text, Dossier) = 0) then begin
          P := P.Item[I];
          Stop := True;
          Break;
        end;
      end;

      if not Stop then Break;

      Dossier := Copy(Value, 1, Pos('\', Value) - 1);
      Delete(Value, 1, Pos('\', Value));
    end;
  end;
  if Assigned(P) then begin
    P.Selected := True;
    P.Expand(False);
  end;
end;

procedure TFormOptions.BitBtnDeleteClick(Sender: TObject);
var D: TDirectory;
    CRC: LongWord;
    Dossier: String;
begin
  Dossier := PathSelected(TreeViewSearch.Selected);
  case TreeViewSearch.Selected.ImageIndex of
    5, 9 : begin // Nous avons un dossier
      FTreeSearch.Browse(PathSelected(TreeViewSearch.Selected)).Delete;
    end;
    7    : begin // C'est un groupe
      D := FTreeSearch.Browse(PathSelected(TreeViewSearch.Selected));
      CRC := TGroup(FGroupList[FGroupList.IndexOf(TreeViewSearch.Selected.Text)]).CRC;
      D.Groups.Delete(D.IndexOf(CRC));
    end;
    else ;   // Cas inconnue, Autre
  end;
  LoadTree;
  PathSelect(Dossier);
  OptionsMgr.Modify;
end;

function TFormOptions.GetOptions: TOptionsManager;
begin
  result := FormSearch.OptionsMgr;
end;

end.
