unit OptionsManager;

interface

uses Classes, BaseRegistry, SearchObject, LogManager, PluginsManager;

type
  TGlobalOptions = record
    Details,
    Minimize,
    TrayIcon  : boolean;
    XPos,
    YPos      : Integer;
  end;

  TLogEvent = set of (leTimeSearch, leSizeFree, leDeletedFile, leWarning, leError, leStdClean);

  TLogOptions = record
    Active,
    EraseOldFile: boolean;
    Events      : TLogEvent;
    Directory   : string;
  end;

  TAction = (fcaDelete, fcaTrash, fcaNone);

  TFileActions   = record
    fcAskBefore : boolean;
    fcAction    : TAction;
  end;

  TPersonalSearchOptions = record
    Active         : boolean;
    OrdinaryFiles,
    ArchivedFiles,
    ReadOnlyFiles,
    HiddenFiles,
    SystemsFiles   : TFileActions;
    GroupList      : TGroupList;
    DriveList      : TDrives;
  end;

  TDebugOptions = record
    NoStandard,
    NoDelete,
    DetailsLog  : boolean;
  end;

  TOptionsManager = class(TBaseRegistry)
  private
    FDebugOptions: TDebugOptions;
    FGlobal: TGlobalOptions;
    FLog: TLogOptions;
    FPersonalSearch: TPersonalSearchOptions;
    FNettoyageStd: TStrings;

    FLogManager : TLogManager;
    FPluginsList: TPluginsManager;

    procedure NettoyageStdModified(Sender: TObject);
    procedure SetDebugDetailsLog(const Value: boolean);
    procedure SetDebugNoDelete(const Value: boolean);
    procedure SetDebugNoStandard(const Value: boolean);
    procedure SetGlobalDetails(const Value: boolean);
    procedure SetGlobalMinimize(const Value: boolean);
    procedure SetGlobalTrayIcon(const Value: boolean);
    procedure SetGlobalXPos(const Value: Integer);
    procedure SetGlobalYPos(const Value: Integer);
    procedure SetLogActive(const Value: boolean);
    procedure SetLogDirectory(const Value: string);
    procedure SetLogEraseOldFile(const Value: boolean);
    procedure SetLogEvents(const Value: TLogEvent);
    procedure SetPersonalSearchActive(const Value: boolean);
    procedure SetPersonalSearchArchivedFiles(const Value: TFileActions);
    procedure SetPersonalSearchHiddenFiles(const Value: TFileActions);
    procedure SetPersonalSearchOrdinaryFiles(const Value: TFileActions);
    procedure SetPersonalSearchReadOnlyFiles(const Value: TFileActions);
    procedure SetPersonalSearchSystemsFiles(const Value: TFileActions);
  protected
    function ChangeToOldValue: Boolean; override;
  public
    constructor Create;
    destructor Destroy; override;

    procedure Default; override;
    procedure SaveToRegistry; override;
    procedure LoadFromRegistry; override;

    procedure Modify;

    property Global: TGlobalOptions read FGlobal;
    property GlobalDetails: boolean read FGlobal.Details write SetGlobalDetails;
    property GlobalMinimize: boolean read FGlobal.Minimize write SetGlobalMinimize;
    property GlobalTrayIcon: boolean read FGlobal.TrayIcon write SetGlobalTrayIcon;
    property GlobalXPos: Integer read FGlobal.XPos write SetGlobalXPos;
    property GlobalYPos: Integer read FGlobal.YPos write SetGlobalYPos;

    property Log: TLogOptions read FLog;
    property LogActive: boolean read FLog.Active write SetLogActive;
    property LogEraseOldFile: boolean read FLog.EraseOldFile write SetLogEraseOldFile;
    property LogEvents: TLogEvent read FLog.Events write SetLogEvents;
    property LogDirectory: string read FLog.Directory write SetLogDirectory;

    property PersonalSearch: TPersonalSearchOptions read FPersonalSearch;
    property PersonalSearchActive: boolean read FPersonalSearch.Active write SetPersonalSearchActive;
    property PersonalSearchOrdinaryFiles: TFileActions read FPersonalSearch.OrdinaryFiles write SetPersonalSearchOrdinaryFiles;
    property PersonalSearchArchivedFiles: TFileActions read FPersonalSearch.ArchivedFiles write SetPersonalSearchArchivedFiles;
    property PersonalSearchReadOnlyFiles: TFileActions read FPersonalSearch.ReadOnlyFiles write SetPersonalSearchReadOnlyFiles;
    property PersonalSearchHiddenFiles: TFileActions read FPersonalSearch.HiddenFiles write SetPersonalSearchHiddenFiles;
    property PersonalSearchSystemsFiles: TFileActions read FPersonalSearch.SystemsFiles write SetPersonalSearchSystemsFiles;

    property DebugOptions: TDebugOptions read FDebugOptions;
    property DebugNoStandard: boolean read FDebugOptions.NoStandard write SetDebugNoStandard;
    property DebugNoDelete: boolean read FDebugOptions.NoDelete write SetDebugNoDelete;
    property DebugDetailsLog: boolean read FDebugOptions.DetailsLog write SetDebugDetailsLog;

    property NettoyageStd: TStrings read FNettoyageStd;

    property PluginsList: TPluginsManager read FPluginsList;
    property LogManager: TLogManager read FLogManager;
  end;

implementation

uses SysUtils, VerManag;

const
  (* Version 4.0 seul *)
  rsNettoyage      = 'Nettoyage';
    rsCleanTrash   = 'Vider la corbeille';
    rsCleanTemp    = 'Vider le dossier temporaire';
    rsPerso        = 'Recherche personnelle';
    rsSd2Trash     = 'Envoyer les elements dans la corbeille';
    rsConfirm      = 'Confirmer la suppression';
    rsTest         = 'Tester';
    rsROHConfirm   = 'Confirmer la suppression des fichiers RO et H';
  rsPersonel       = 'Personnel';
    rsPersoSearch  = 'Recherche personnelle';
  (* Version 4.0 et Version 5.0 *)
  rsAffichage      = 'Affichage';
    rsDetail       = 'Afficher le detail';
    rsReduce       = 'Mettre en icone';
    rsXPos         = 'Position en X';
    rsYPos         = 'Position en Y';
  rsJournal        = 'Journal';
    rsActiveLog    = 'Activer la journalisation';
    rsDirectory    = 'Emplacement du journal';
    rsEvents       = 'Evenements';
    rsNewLog       = 'Nouveau journal  chaque recherche';
  (* Version 5.0 seul *)
//rsAffichage      = 'Affichage';
    rsReduceInTray = 'Icone avec l''horloge';
  rsNettoyageStd   = 'Nettoyage Standard';
//rsPersonel       = 'Personnel';
    rsActiveSearch = 'Activer la recherche personnelle';
    rsGroupSearch  = 'Groupe de masque de recherche';
    rsTreeSearch   = 'Arbre de recherche';
    rsOrdinaryFiles= 'Action pour les fichiers ordinaires';
    rsArchiveFiles = 'Action pour les fichiers archivs';
    rsReadOnlyFiles= 'Action pour les fichiers en lecture seul';
    rsHiddenFiles  = 'Action pour les fichiers cachs';
    rsSystemFiles  = 'Action pour les fichiers systmes';
  rsDebug          = 'Debuggage';
    rsNoStdClean   = 'Ne pas faire de nettoyage standard';
    rsNoDeleteFiles= 'Ne pas supprimer de fichier';
    rsLogPlus      = 'Journal dtaill';

(* Options par dfaut *)

// Version 4
//                    Journal
  dfCleanTrash     = true;
  dfCleanTemp      = true;
  dfPerso          = true;
  dfSd2Trash       = true;
  dfConfirm        = true;
  dfTest           = false;
  dfROHConfirm     = 2;

// Version 5
//                    Affichage
    dfDetail       = False;
    dfReduce       = True;
    dfReduceInTray = True;
//                    Journal
    dfActiveLog    = True;
    dfEvents:Byte  = $3F; // Tous = 111111
    dfNewLog       = True;
//                    Personnel
    dfActiveSearch = True;
    dfOrdinaryFiles= $81;
    dfArchiveFiles = $81;
    dfReadOnlyFiles= $81;
    dfHiddenFiles  = $02;
    dfSystemFiles  = $02;
//                    Debuggage
    dfNoStdClean   = False;
    dfNoDeleteFiles= False;
    dfLogPlus      = True;

var
  dfNettoyageStd   : string;

{ TOptionsManager }

function TOptionsManager.ChangeToOldValue: Boolean;
const OldCompany = 'Phoenix-Logi';
begin
  if Company = OldCompany then
    result := false
  else begin
    Company := OldCompany;
    result := true;
  end;
end;

constructor TOptionsManager.Create;
begin
  inherited Create;

  FLogManager := TLogManager.Create(Self);

  FPluginsList := TPluginsManager.Create(ExtractFilePath(ParamStr(0)));

  FNettoyageStd := TStringList.Create;
  (FNettoyageStd as TStringList).OnChange := NettoyageStdModified;

  FPersonalSearch.GroupList := TGroupList.Create;
  FPersonalSearch.DriveList := TDrives.Create(FPersonalSearch.GroupList);
end;

procedure TOptionsManager.Default;
var I: Integer;
begin
  with FGlobal do begin
    Details   := dfDetail;
    Minimize  := dfReduce;
    TrayIcon  := dfReduceInTray;
  end;

  with FLog do begin
    Active      := dfActiveLog;
    EraseOldFile:= dfNewLog;
    Events      := TLogEvent(dfEvents);
    Directory   := ExtractFilePath(ParamStr(0));
    FLogManager.DirName := Directory;
  end;

  with FPersonalSearch do begin
    Active         := dfActiveSearch;
    with OrdinaryFiles do begin
      fcAskBefore := Boolean(dfOrdinaryFiles shr 7);
      fcAction    := TAction(dfOrdinaryFiles and $7F);
    end;
    with ArchivedFiles do begin
      fcAskBefore := Boolean(dfArchiveFiles shr 7);
      fcAction    := TAction(dfArchiveFiles and $7F);
    end;
    with ReadOnlyFiles do begin
      fcAskBefore := Boolean(dfReadOnlyFiles shr 7);
      fcAction    := TAction(dfReadOnlyFiles and $7F);
    end;
    with HiddenFiles do begin
      fcAskBefore := Boolean(dfHiddenFiles shr 7);
      fcAction    := TAction(dfHiddenFiles and $7F);
    end;
    with SystemsFiles do begin
      fcAskBefore := Boolean(dfSystemFiles shr 7);
      fcAction    := TAction(dfSystemFiles and $7F);
    end;

    if Assigned(GroupList) then GroupList.Clear;
    if Assigned(DriveList) then DriveList.Clear;
  end;

  with FDebugOptions do begin
    NoStandard := dfNoStdClean;
    NoDelete   := dfNoDeleteFiles;
    DetailsLog := dfLogPlus;
  end;

  if Assigned(FNettoyageStd) then begin
    FNettoyageStd.Clear;
    for I := 0 to PluginsList.Count - 1 do begin
      if PluginsList.Items[I].pIsCheckDefault then
        FNettoyageStd.Add(PluginsList.Items[I].pIdentificateur);
    end;
    dfNettoyageStd := FNettoyageStd.CommaText;
  end;
end;

destructor TOptionsManager.Destroy;
begin
  FPersonalSearch.DriveList.Free;
  FPersonalSearch.GroupList.Free;
  FNettoyageStd.Free;
  FPluginsList.Free;
  FLogManager.Free;
  inherited;
end;

procedure TOptionsManager.LoadFromRegistry;
var Events, Action            : Byte;
    Index1, Index2, StreamSize: Integer;
    Accept                    : Boolean;
    Stream                    : TMemoryStream;
begin
  inherited;
  if Registry.OpenKey(getVersionKey + '\' + rsAffichage, false) then try
    FGlobal.Details  := ReadValue(rsDetail, dfDetail);
    FGlobal.Minimize := ReadValue(rsReduce, dfReduce);
    FGlobal.TrayIcon := ReadValue(rsReduceInTray, dfReduceInTray);
    FGlobal.XPos     := ReadValue(rsXPos, -1);
    FGlobal.YPos     := ReadValue(rsYPos, -1);
  finally
    Registry.CloseKey;
  end;

  if Registry.OpenKey(getVersionKey + '\' + rsJournal, false) then try
    FLog.Active       := ReadValue(rsActiveLog, dfActiveLog);
    FLog.EraseOldFile := ReadValue(rsNewLog, dfNewLog);
    Events := ReadValue(rsEvents, dfEvents);
    FLog.Events       := TLogEvent(Events);
    FLog.Directory    := ReadValue(rsDirectory, ExtractFilePath(ParamStr(0)));
    FLogManager.DirName := FLog.Directory;
  finally
    Registry.CloseKey;
  end;

  if CompareVersion(ComposeVersion(CurrVer), ComposeVersion('5')) >= 0 then begin
    if Registry.OpenKey(getVersionKey + '\' + rsPersonel, false) then try
      with FPersonalSearch do begin
        Active         := ReadValue(rsActiveSearch, dfActiveSearch);
        with OrdinaryFiles do begin
          Action      := ReadValue(rsOrdinaryFiles, dfOrdinaryFiles);
          fcAskBefore := Boolean(Action shr 7);
          fcAction    := TAction(Action and $7F);
        end;
        with ArchivedFiles do begin
          Action      := ReadValue(rsArchiveFiles, dfArchiveFiles);
          fcAskBefore := Boolean(Action shr 7);
          fcAction    := TAction(Action and $7F);
        end;
        with ReadOnlyFiles do begin
          Action      := ReadValue(rsReadOnlyFiles, dfReadOnlyFiles);
          fcAskBefore := Boolean(Action shr 7);
          fcAction    := TAction(Action and $7F);
        end;
        with HiddenFiles do begin
          Action      := ReadValue(rsHiddenFiles, dfHiddenFiles);
          fcAskBefore := Boolean(Action shr 7);
          fcAction    := TAction(Action and $7F);
        end;
        with SystemsFiles do begin
          Action      := ReadValue(rsSystemFiles, dfSystemFiles);
          fcAskBefore := Boolean(Action shr 7);
          fcAction    := TAction(Action and $7F);
        end;

        if Registry.ValueExists(rsGroupSearch) then begin
          Stream := TMemoryStream.Create;
          try
            StreamSize := Registry.GetDataSize(rsGroupSearch);
            Stream.Size := StreamSize;
            Registry.ReadBinaryData(rsGroupSearch, Stream.Memory^, StreamSize);
            GroupList.LoadFromStream(Stream);
            DriveList.Clear;
          finally
            Stream.Free;
          end;
        end;

        if Registry.ValueExists(rsTreeSearch) then begin
          Stream := TMemoryStream.Create;
          try
            StreamSize := Registry.GetDataSize(rsTreeSearch);
            Stream.Size := StreamSize;
            Registry.ReadBinaryData(rsTreeSearch, Stream.Memory^, StreamSize);
            DriveList.LoadFromStream(Stream);
          finally
            Stream.Free;
          end;
        end;    
      end;
    finally
      Registry.CloseKey;
    end;

    if Registry.OpenKey(getVersionKey + '\' + rsDebug, false) then try
      FDebugOptions.NoStandard := ReadValue(rsNoStdClean, dfNoStdClean);
      FDebugOptions.NoDelete   := ReadValue(rsNoDeleteFiles, dfNoDeleteFiles);
      FDebugOptions.DetailsLog := ReadValue(rsLogPlus, dfLogPlus);
    finally
      Registry.CloseKey;
    end;

    if Registry.OpenKey(getVersionKey, false) then try
      FNettoyageStd.CommaText := ReadValue(rsNettoyageStd, dfNettoyageStd);
    finally
      Registry.CloseKey;
    end;
  end else begin
    if Registry.OpenKey(getVersionKey + '\' + rsNettoyage, false) then try
      // Corbeille
      Index1 := FNettoyageStd.IndexOf('922FC1-03090632-8363170C');
      Accept := ReadValue(rsCleanTrash, dfCleanTrash);
      if (Index1 <> -1) and (not Accept) then
        FNettoyageStd.Delete(Index1)
      else
      if (Index1 = -1) and Accept then
        FNettoyageStd.Add('922FC1-03090632-8363170C');

      // Dossier Temporaire
      Index1 := FNettoyageStd.IndexOf('D75A31-03090632-0A5B6CE5');
      Index2 := FNettoyageStd.IndexOf('6BC02B-03090632-B3435569');
      Accept := ReadValue(rsCleanTemp, dfCleanTemp);
      if ((Index1 <> -1) or (Index2 <> -1)) and (not Accept) then begin
        if Index1 <> -1 then FNettoyageStd.Delete(Index1);
        if Index2 <> -1 then FNettoyageStd.Delete(Index2);
      end else begin
        if (Index1 = -1) and Accept then
          FNettoyageStd.Add('D75A31-03090632-0A5B6CE5');
        if (Index2 = -1) and Accept then
          FNettoyageStd.Add('6BC02B-03090632-B3435569');
      end;

      FPersonalSearch.Active    := ReadValue(rsPerso, dfPerso);
      if ReadValue(rsSd2Trash, dfSd2Trash) then begin
        FPersonalSearch.OrdinaryFiles.fcAction := fcaTrash;
        FPersonalSearch.ArchivedFiles.fcAction := fcaTrash;
        FPersonalSearch.ReadOnlyFiles.fcAction := fcaTrash;
        FPersonalSearch.HiddenFiles.fcAction := fcaTrash;
      end else begin
        FPersonalSearch.OrdinaryFiles.fcAction := fcaDelete;
        FPersonalSearch.ArchivedFiles.fcAction := fcaDelete;
        FPersonalSearch.ReadOnlyFiles.fcAction := fcaDelete;
        FPersonalSearch.HiddenFiles.fcAction := fcaDelete;
      end;

      if ReadValue(rsROHConfirm, dfROHConfirm) <> 0 then begin
        FPersonalSearch.ReadOnlyFiles.fcAction := fcaNone;
        FPersonalSearch.HiddenFiles.fcAction := fcaNone;
      end;

      FPersonalSearch.SystemsFiles.fcAction := fcaNone;

      if ReadValue(rsConfirm, dfConfirm) then begin
        FPersonalSearch.OrdinaryFiles.fcAskBefore := True;
        FPersonalSearch.ArchivedFiles.fcAskBefore := True;
        FPersonalSearch.ReadOnlyFiles.fcAskBefore := True;
        FPersonalSearch.HiddenFiles.fcAskBefore := True;
        FPersonalSearch.SystemsFiles.fcAskBefore := True;
      end else begin
        FPersonalSearch.OrdinaryFiles.fcAskBefore := False;
        FPersonalSearch.ArchivedFiles.fcAskBefore := False;
        FPersonalSearch.ReadOnlyFiles.fcAskBefore := False;
        FPersonalSearch.HiddenFiles.fcAskBefore := False;
        FPersonalSearch.SystemsFiles.fcAskBefore := False;
      end;
      FDebugOptions.NoDelete := ReadValue(rsTest, dfTest);
    finally
      Registry.CloseKey;
    end;

    if Registry.OpenKey(getVersionKey + '\' + rsPersonel, false) then try
      if Registry.ValueExists(rsPersoSearch) then begin
        Stream := TMemoryStream.Create;
        try
          StreamSize := Registry.GetDataSize(rsPersoSearch);
          Stream.Size := StreamSize;
          Registry.ReadBinaryData(rsPersoSearch, Stream.Memory^, StreamSize);
          FPersonalSearch.DriveList.LoadFromStream3(Stream);
        finally
          Stream.Free;
        end;
      end;
    finally
      Registry.CloseKey;
    end;
  end;

  ResetModified;
end;

procedure TOptionsManager.Modify;
begin
  PropertyModified;
end;

procedure TOptionsManager.NettoyageStdModified(Sender: TObject);
begin
  PropertyModified;
end;

procedure TOptionsManager.SaveToRegistry;
var Stream: TMemoryStream;
begin
  inherited;

  if Registry.OpenKey(getVersionKey, true) then try
    WriteValue(rsNettoyageStd, FNettoyageStd.CommaText, dfNettoyageStd);
  finally
    Registry.CloseKey;
  end;

  if Registry.OpenKey(getVersionKey + '\' + rsAffichage, true) then try
    WriteValue(rsDetail, FGlobal.Details, dfDetail);
    WriteValue(rsReduce, FGlobal.Minimize, dfReduce);
    WriteValue(rsReduceInTray, FGlobal.TrayIcon, dfReduceInTray);
    WriteValue(rsXPos, FGlobal.XPos, -1);
    WriteValue(rsYPos, FGlobal.YPos, -1);
  finally
    Registry.CloseKey;
  end;

  if Registry.OpenKey(getVersionKey + '\' + rsJournal, true) then try
    WriteValue(rsActiveLog, FLog.Active, dfActiveLog);
    WriteValue(rsNewLog, FLog.EraseOldFile, dfNewLog);
    WriteValue(rsEvents, Byte(FLog.Events), dfEvents);
    WriteValue(rsDirectory, FLog.Directory, ExtractFilePath(ParamStr(0)));
  finally
    Registry.CloseKey;
  end;

  if Registry.OpenKey(getVersionKey + '\' + rsPersonel, true) then try
    WriteValue(rsActiveSearch, FPersonalSearch.Active, dfActiveSearch);

    with FPersonalSearch.OrdinaryFiles do begin
      WriteValue(rsOrdinaryFiles,
                (Byte(fcAction) and $7F) + (Integer(fcAskBefore) shl 7),
                dfOrdinaryFiles);
    end;
    with FPersonalSearch.ArchivedFiles do begin
      WriteValue(rsArchiveFiles,
                (Byte(fcAction) and $7F) + (Integer(fcAskBefore) shl 7),
                dfArchiveFiles);
    end;
    with FPersonalSearch.ReadOnlyFiles do begin
      WriteValue(rsReadOnlyFiles,
                (Byte(fcAction) and $7F) + (Integer(fcAskBefore) shl 7),
                dfReadOnlyFiles);
    end;
    with FPersonalSearch.HiddenFiles do begin
      WriteValue(rsHiddenFiles,
                (Byte(fcAction) and $7F) + (Integer(fcAskBefore) shl 7),
                dfHiddenFiles);
    end;
    with FPersonalSearch.SystemsFiles do begin
      WriteValue(rsSystemFiles,
                (Byte(fcAction) and $7F) + (Integer(fcAskBefore) shl 7),
                dfSystemFiles);
    end;

    Stream := TMemoryStream.Create;
    try
      FPersonalSearch.GroupList.SaveToStream(Stream);
      Registry.WriteBinaryData(rsGroupSearch, Stream.Memory^, Stream.Size);
    finally
      Stream.Free;
    end;

    Stream := TMemoryStream.Create;
    try
      FPersonalSearch.DriveList.SaveToStream(Stream);
      Registry.WriteBinaryData(rsTreeSearch, Stream.Memory^, Stream.Size);
    finally
      Stream.Free;
    end;
  finally
    Registry.CloseKey;
  end;

  if Registry.OpenKey(getVersionKey + '\' + rsDebug, true) then try
    WriteValue(rsNoStdClean, FDebugOptions.NoStandard, dfNoStdClean);
    WriteValue(rsNoDeleteFiles, FDebugOptions.NoDelete, dfNoDeleteFiles);
    WriteValue(rsLogPlus, FDebugOptions.DetailsLog, dfLogPlus);
  finally
    Registry.CloseKey;
  end;

  ResetModified;
end;

procedure TOptionsManager.SetDebugDetailsLog(const Value: boolean);
begin
  if FDebugOptions.DetailsLog <> Value then begin
    FDebugOptions.DetailsLog := Value;
    PropertyModified;
  end;
end;

procedure TOptionsManager.SetDebugNoDelete(const Value: boolean);
begin
  if FDebugOptions.NoDelete <> Value then begin
    FDebugOptions.NoDelete := Value;
    PropertyModified;
  end;
end;

procedure TOptionsManager.SetDebugNoStandard(const Value: boolean);
begin
  if FDebugOptions.NoStandard <> Value then begin
    FDebugOptions.NoStandard := Value;
    PropertyModified;
  end;
end;

procedure TOptionsManager.SetGlobalDetails(const Value: boolean);
begin
  if FGlobal.Details <> Value then begin
    FGlobal.Details := Value;
    PropertyModified;
  end;
end;

procedure TOptionsManager.SetGlobalMinimize(const Value: boolean);
begin
  if FGlobal.Minimize <> Value then begin
    FGlobal.Minimize := Value;
    PropertyModified;
  end;
end;

procedure TOptionsManager.SetGlobalTrayIcon(const Value: boolean);
begin
  if FGlobal.TrayIcon <> Value then begin
    FGlobal.TrayIcon := Value;
    PropertyModified;
  end;
end;

procedure TOptionsManager.SetGlobalXPos(const Value: Integer);
begin
  if FGlobal.XPos <> Value then begin
    FGlobal.XPos := Value;
    PropertyModified;
  end;
end;

procedure TOptionsManager.SetGlobalYPos(const Value: Integer);
begin
  if FGlobal.YPos <> Value then begin
    FGlobal.YPos := Value;
    PropertyModified;
  end;
end;

procedure TOptionsManager.SetLogActive(const Value: boolean);
begin
  if FLog.Active <> Value then begin
    FLog.Active := Value;
    PropertyModified;
  end;
end;

procedure TOptionsManager.SetLogDirectory(const Value: string);
begin
  if FLog.Directory <> Value then begin
    FLog.Directory := Value;
    FLogManager.DirName := Value;
    PropertyModified;
  end;
end;

procedure TOptionsManager.SetLogEraseOldFile(const Value: boolean);
begin
  if FLog.EraseOldFile <> Value then begin
    FLog.EraseOldFile := Value;
    PropertyModified;
  end;
end;

procedure TOptionsManager.SetLogEvents(const Value: TLogEvent);
begin
  if FLog.Events <> Value then begin
    FLog.Events := Value;
    PropertyModified;
  end;
end;

procedure TOptionsManager.SetPersonalSearchActive(const Value: boolean);
begin
  if FPersonalSearch.Active <> Value then begin
    FPersonalSearch.Active := Value;
    PropertyModified;
  end;
end;

procedure TOptionsManager.SetPersonalSearchArchivedFiles(
  const Value: TFileActions);
begin
  if (FPersonalSearch.ArchivedFiles.fcAskBefore <> Value.fcAskBefore) or
     (FPersonalSearch.ArchivedFiles.fcAction <> Value.fcAction)       then begin
    FPersonalSearch.ArchivedFiles := Value;
    PropertyModified;
  end;
end;

procedure TOptionsManager.SetPersonalSearchHiddenFiles(
  const Value: TFileActions);
begin
  if (FPersonalSearch.HiddenFiles.fcAskBefore <> Value.fcAskBefore) or
     (FPersonalSearch.HiddenFiles.fcAction <> Value.fcAction)       then begin
    FPersonalSearch.HiddenFiles := Value;
    PropertyModified;
  end;
end;

procedure TOptionsManager.SetPersonalSearchOrdinaryFiles(
  const Value: TFileActions);
begin
  if (FPersonalSearch.OrdinaryFiles.fcAskBefore <> Value.fcAskBefore) or
     (FPersonalSearch.OrdinaryFiles.fcAction <> Value.fcAction)       then begin
    FPersonalSearch.OrdinaryFiles := Value;
    PropertyModified;
  end;
end;

procedure TOptionsManager.SetPersonalSearchReadOnlyFiles(
  const Value: TFileActions);
begin
  if (FPersonalSearch.ReadOnlyFiles.fcAskBefore <> Value.fcAskBefore) or
     (FPersonalSearch.ReadOnlyFiles.fcAction <> Value.fcAction)       then begin
    FPersonalSearch.ReadOnlyFiles := Value;
    PropertyModified;
  end;
end;

procedure TOptionsManager.SetPersonalSearchSystemsFiles(
  const Value: TFileActions);
begin
  if (FPersonalSearch.SystemsFiles.fcAskBefore <> Value.fcAskBefore) or
     (FPersonalSearch.SystemsFiles.fcAction <> Value.fcAction)       then begin
    FPersonalSearch.SystemsFiles := Value;
    PropertyModified;
  end;
end;

end.
