unit PluginsManager;

interface

uses Classes, PluginsTypes;

type
  TPluginsManager = class
  private
    FLibArray: array [Byte] of THandle;
    FLibArrayCount: Byte;
    FProcList: TList;

    procedure LoadPlugins(const FileName: string);

    function GetItem(Index: Integer): TPlugin;
    function GetCount: Integer;
  public
    constructor Create(const Directory: String);
    destructor Destroy; override;

    function PluginsOf(Serial: TSerialNumber): TPlugin;

    property Items[Index: Integer]: TPlugin read GetItem;
    property Count: Integer read GetCount;
  end;

implementation

uses Windows, FileTools, SysUtils;

{ TPluginsManager }

function Compare(Item1, Item2: Pointer): Integer;
begin
  result := Integer(PPlugin(Item1).pLibType) - Integer(PPlugin(Item2).pLibType);
  if Result = 0 then
    Result := CompareStr(PPlugin(Item1).pDescription, PPlugin(Item2).pDescription)
end;

constructor TPluginsManager.Create(const Directory: String);
var SRec: TSearchRec;
    Res : Integer;
    PlugName: string;
begin
  FLibArrayCount := 0;
  FProcList := TList.Create;

  Res := FindFirst(IncludeTrailingPathDelimiter(Directory) + '*.xdl', faAnyFile, SRec);
  while Res = 0 do begin
    PlugName := IncludeTrailingPathDelimiter(Directory) + SRec.Name;
    LoadPlugins(PlugName);
    Res := FindNext(sRec);
  end;
  FindClose(SRec);

  FProcList.Sort(Compare);
end;

destructor TPluginsManager.Destroy;
var I: Integer;
begin
  FProcList.Free;
  for I := 0 to FLibArrayCount - 1 do
    FreeLibrary(FLibArray[I]);
end;

function TPluginsManager.GetCount: Integer;
begin
  result := FProcList.Count;
end;

function TPluginsManager.GetItem(Index: Integer): TPlugin;
begin
  result := PPlugin(FProcList[Index])^;
end;

procedure TPluginsManager.LoadPlugins(const FileName: string);
var HLib    : THandle;
    GetCount: TGetCountPlugins;
    GetPlug : TGetPlugin;
    Cnt, I  : Integer;
begin
  HLib := LoadLibrary(PChar(FileName));
  if HLib <> 0 then begin
    GetCount := GetProcAddress(HLib, 'GetCountPlugins');
    GetPlug := GetProcAddress(HLib, 'GetPlugin');
    Cnt := GetCount;

    for I := 0 to Cnt - 1 do
      FProcList.Add(GetPlug(I));

    FLibArray[FLibArrayCount] := HLib;
    Inc(FLibArrayCount);
  end;
end;

function TPluginsManager.PluginsOf(Serial: TSerialNumber): TPlugin;
var I: Integer;
begin
  for I := 0 to Count - 1 do
    if Items[I].pIdentificateur = Serial then begin
      result := Items[I];
      Break;
    end;
end;

end.
