unit PluginsObjectThread;

interface

uses
  Classes, Windows, OptionsManager, LogManager, FileTools;

type
  TPluginsObject = class(TThread)
  private
    FLine: string;
    FLinePriority: TLinePriority;
    FProgress: Integer;
    FTotalSize: Int64;
    procedure AddLogLine;
    procedure ProgressUpdate;

    procedure LogLine(Text: string; Prio: TLinePriority);
    procedure SetName;
    function GetOptions: TOptionsManager;
  protected
    procedure Execute; override;
    property OptionsMgr: TOptionsManager read GetOptions;
  public
    constructor Create();

    property TotalSize: Int64 read FTotalSize;
  end;

implementation

uses SysUtils, PluginsTypes, SearchForm, resources;

type
  TThreadNameInfo = record
    FType: LongWord;     // doit tre 0x1000
    FName: PChar;        // pointeur sur le nom (dans l'espace d'adresse de l'utilisateur)
    FThreadID: LongWord; // ID de thread (-1=thread de l'appelant)
    FFlags: LongWord;    // rserv pour une future utilisation, doit tre zro
  end;

{ TPluginsObject }

procedure TPluginsObject.SetName;
var
  ThreadNameInfo: TThreadNameInfo;
begin
  ThreadNameInfo.FType := $1000;
  ThreadNameInfo.FName := 'Plugins Object Thread';
  ThreadNameInfo.FThreadID := $FFFFFFFF;
  ThreadNameInfo.FFlags := 0;

  try
    RaiseException( $406D1388, 0, sizeof(ThreadNameInfo) div sizeof(LongWord), @ThreadNameInfo );
  except
  end;
end;

procedure TPluginsObject.Execute;
var R, I   : Integer;
    G      : TPlugin;
    IncSize: Int64;
begin
  SetName;
  IncSize := 0;
  LogLine(EmptyStr, lpNone);
  LogLine('Starting first step of analyse', lpDebug);
  for I := 0 to OptionsMgr.PluginsList.Count - 1 do begin
    FProgress := I;
    G := OptionsMgr.PluginsList.Items[I];

    if OptionsMgr.NettoyageStd.IndexOf(G.pIdentificateur) >= 0 then begin
      LogLine(Format(rsStartClean, [G.pDescription]), lpNone);
      LogLine('ID = ' + G.pIdentificateur, lpDebug);
      if Assigned(G.pCleanFunc) then begin
        if not (OptionsMgr.Debug and OptionsMgr.DebugOptions.NoStandard) then
          R := G.pCleanFunc
        else
          R := -1;
        if R >= 0 then begin
          LogLine(Format(rsEndCleanWithSize, [G.pDescription, SizeToStr(R)]), lpStdWork);
          Inc(IncSize, R);
        end else
          if R = -1 then
            LogLine(Format(rsEndCleanWithoutSize, [G.pDescription]), lpStdWork)
          else
            LogLine(Format(rsEndError, [G.pDescription, rsErrorNumber + IntToStr(-R)]), lpWarning)
      end else begin
        LogLine(Format(rsEndError, [G.pDescription, rsXDLFileNotFound]), lpError);
      end;                                               
    end;
    Synchronize(ProgressUpdate);
    if Terminated then break;
  end;
  LogLine('Stopping first step of analyse', lpDebug);
  FTotalSize := IncSize;
end;

procedure TPluginsObject.AddLogLine;
begin
  OptionsMgr.LogManager.Add(FLine, FLinePriority);
end;

procedure TPluginsObject.LogLine(Text: string; Prio: TLinePriority);
begin
  FLine := Text;
  FLinePriority := Prio;
  Synchronize(AddLogLine);
end;

constructor TPluginsObject.Create;
begin
  inherited Create(true);
  FreeOnTerminate := True;
  FProgress := -1;
  ProgressUpdate;
end;

procedure TPluginsObject.ProgressUpdate;
begin
  FormSearch.ProgressBar.Max := OptionsMgr.PluginsList.Count;
  FormSearch.ProgressBar.Position := FProgress + 1;
end;

function TPluginsObject.GetOptions: TOptionsManager;
begin
  result := FormSearch.OptionsMgr;
end;

end.
