unit SearchForm;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ComCtrls, JvComponent, JvBalloonHint, IAgaloLED,
  ExtCtrls, Contnrs, JvTrayIcon, ShareMemUtils, JvArrowBtn, Menus,
  OptionsManager, LogManager;

type
  TFormSearch = class(TForm)
    ButtonOptions: TButton;
    ButtonStartStop: TButton;
    ButtonClose: TButton;
    ButtonUpdate: TButton;
    AnimateProgress: TAnimate;
    LEDError: TIAgaloLED;
    LEDWarning: TIAgaloLED;
    LEDWork: TIAgaloLED;
    ProgressBar: TProgressBar;
    LabelStatus: TLabel;
    BevelCadre: TBevel;
    BevelDetails: TBevel;
    RichEditLog: TRichEdit;
    BevelBottom: TBevel;
    ButtonAbout: TButton;
    procedure ButtonOptionsClick(Sender: TObject);
    procedure ButtonAboutClick(Sender: TObject);
    procedure ButtonCloseClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure ButtonStartStopClick(Sender: TObject);
    procedure ButtonUpdateClick(Sender: TObject);
  private
    { Dclarations prives }
    FXDLEvent: TThreadWaitForEvent;

    FSearchThread,
    FPluginsThread: TThread;
    FFileList: TObjectList;
    FWorkStat: array[1..2] of boolean;

    FStartTime: LongWord;
    FOptionsMgr: TOptionsManager;

    FAutoStart: boolean;
    FAutoStop: boolean;
    FIconize: boolean;
    FSilentMode: boolean;

    procedure LogChange(const LineAdded: string; const Priority: TLinePriority);

    procedure ActivateSignal(Sender: TObject);
    procedure PluginsObjectTerminate(Sender: TObject);
    procedure SearchObjectTerminate(Sender: TObject);

    function GetWorkStat(Index: Integer): boolean;
    procedure SetWorkStat(Index: Integer; const Value: boolean);
    function getAutoStop: boolean;
    function getIconize: boolean;
  public
    { Dclarations publiques }
    procedure InitializeSoftware;
    procedure FinalizeSoftware;

    property AutoStart: boolean read FAutoStart write FAutoStart;
    property AutoStop: boolean read getAutoStop write FAutoStop;
    property Iconize: boolean read getIconize write FIconize;
    property SilentMode: boolean read FSilentMode write FSilentMode;

    property WorkStat[Index: Integer]: boolean read GetWorkStat write SetWorkStat;
    property OptionsMgr: TOptionsManager read FOptionsMgr;
  end;

var
  FormSearch: TFormSearch;

implementation

uses ShellAPI, OptionsForm, AppModule, VerManag, SearchObject, PluginsObjectThread,
  SearchObjectThread, FileListForm, tShellAPI, FileTools, SplashForm,
  resources, Math;

{$R *.dfm}

procedure TFormSearch.ButtonOptionsClick(Sender: TObject);
begin
  FormOptions := TFormOptions.Create(Application);
  try
    FormOptions.ShowModal;
    FinalizeSoftware;
    InitializeSoftware;
  finally
    FreeAndNil(FormOptions);
  end;
end;

procedure TFormSearch.ButtonAboutClick(Sender: TObject);
begin
  DataModuleApplication.AboutDlg.ExecuteAbout2;
  DataModuleApplication.JVCLAbout.Execute;
end;

procedure TFormSearch.ButtonCloseClick(Sender: TObject);
begin
  Close;
end;

procedure TFormSearch.FinalizeSoftware;
begin
  OptionsMgr.GlobalXPos := Left;
  OptionsMgr.GlobalYPos := Top;
  OptionsMgr.SaveToRegistry;

  FOptionsMgr.Free;
end;

procedure TFormSearch.InitializeSoftware;
var I: Integer;
begin
  FOptionsMgr := TOptionsManager.Create;
  FOptionsMgr.LoadFromRegistry;

  if Assigned(FormSplash) then FormSplash.Inc;
  OptionsMgr.LogManager.OnChange := LogChange;

  RichEditLog.Lines.Clear;
  RichEditLog.SelAttributes.Color := clSilver;
  RichEditLog.Lines.Add(HeadGenerator);

  AnimateProgress.Visible := False;
  ProgressBar.Position := 0;

  if Assigned(FormSplash) then FormSplash.Inc;
  OptionsMgr.LogManager.Add('Company          = ' + OptionsMgr.Company, lpDebug);
  OptionsMgr.LogManager.Add('Application Name = ' + OptionsMgr.AppName, lpDebug);
  OptionsMgr.LogManager.Add('Current Version  = ' + OptionsMgr.CurrVer, lpDebug);
  OptionsMgr.LogManager.Add('This Version     = ' + OptionsMgr.Version, lpDebug);
  OptionsMgr.LogManager.Add('Is First Start   = ' + BoolToStr(OptionsMgr.FirstStart, True), lpDebug);

  OptionsMgr.LogManager.Add('Plugins          = ' + OptionsMgr.NettoyageStd.CommaText, lpDebug);

  OptionsMgr.LogManager.Add('Move and Resize Windows', lpDebug);
  if OptionsMgr.Global.Details then
    ClientHeight := BevelBottom.Top
  else
    ClientHeight := BevelDetails.Top;
  Self.SetBounds(OptionsMgr.Global.XPos, OptionsMgr.Global.YPos, Width, Height);
  OptionsMgr.LogManager.Add('Windows Moved and Resizes', lpDebug);

  if OptionsMgr.Debug then begin
    OptionsMgr.LogManager.Add('List of Groups :', lpDebug);
    for I := 0 to OptionsMgr.PersonalSearch.GroupList.Count - 1 do begin
      OptionsMgr.LogManager.Add('  --> ' + TGroup(OptionsMgr.PersonalSearch.GroupList.Items[I]).Name, lpDebug);
    end;
  end;

  WorkStat[0] := False; WorkStat[1] := False;

  if AutoStart then ButtonStartStop.Click;
end;

procedure TFormSearch.FormCreate(Sender: TObject);
begin
  FXDLEvent := TThreadWaitForEvent.Create('XDLEVENT');
  FXDLEvent.OnEventSignal := ActivateSignal;
end;

procedure TFormSearch.FormDestroy(Sender: TObject);
begin
  FXDLEvent.Free;
  FinalizeSoftware;
end;

procedure TFormSearch.LogChange(const LineAdded: string;
  const Priority: TLinePriority);
begin
  ActiveControl := RichEditLog;
  case Priority of
    lpSuccess : RichEditLog.SelAttributes.Color := clLime;
    lpWarning : begin
      RichEditLog.SelAttributes.Color := clYellow;
      LEDWarning.LedOn := True;
    end;
    lpError : begin
      RichEditLog.SelAttributes.Color := clRed;
      LEDError.LedOn := True;
    end;
    lpDebug : RichEditLog.SelAttributes.Color := clTeal;
    else RichEditLog.SelAttributes.Color := clSilver;
  end;

  RichEditLog.Lines.Add(LineAdded);
  RichEditLog.SelAttributes := RichEditLog.DefAttributes;
end;

procedure TFormSearch.ButtonStartStopClick(Sender: TObject);
begin
  if not WorkStat[0] then begin
    if Iconize then begin
      if OptionsMgr.Global.TrayIcon then begin
        DataModuleApplication.SearchTrayIcon.Active := True;
        DataModuleApplication.SearchTrayIcon.Visibility :=
          DataModuleApplication.SearchTrayIcon.Visibility
          - [tvVisibleTaskBar, tvVisibleTaskList];
      end else
        Application.Minimize;
    end;

    WorkStat[1] := True;
    FPluginsThread := TPluginsObject.Create;
    with FPluginsThread do begin
      OnTerminate := PluginsObjectTerminate;
      Resume;
    end;

    if OptionsMgr.PersonalSearch.Active then begin
      WorkStat[2] := True;
      FFileList := TObjectList.Create(True);
      FSearchThread := TSearchObject.Create(FFileList);
      with FSearchThread do begin
        OnTerminate := SearchObjectTerminate;
        Resume;
      end;
    end else
      FSearchThread := nil;
  end else begin
    if Assigned(FPluginsThread) then FPluginsThread.Terminate;
    if Assigned(FSearchThread)  then FSearchThread.Terminate;
  end;
end;

function TFormSearch.GetWorkStat(Index: Integer): boolean;
begin
  case Index of
    1,2 : result := FWorkStat[Index];
    else result := FWorkStat[1] or FWorkStat[2];
  end;
end;

procedure TFormSearch.SetWorkStat(Index: Integer; const Value: boolean);
var OldStat: boolean;
begin
  OldStat := WorkStat[0];

  FWorkStat[Index] := Value;
  LEDWork.LedOn := WorkStat[0];
  if not LEDWork.LedOn then begin
    ButtonStartStop.Caption := rsStartButton;
    ButtonOptions.Enabled := True;
    ButtonClose.Enabled := True;
    ButtonUpdate.Enabled := True;
    AnimateProgress.Visible := False;
    AnimateProgress.Active := False;
  end else begin
    LabelStatus.Caption := '';
    ButtonStartStop.Caption := rsCancelButton;
    ButtonOptions.Enabled := False;
    ButtonClose.Enabled := False;
    ButtonUpdate.Enabled := False;
    AnimateProgress.Visible := True;
    AnimateProgress.Active := True;
  end;

  if (not OldStat) and WorkStat[0] then begin
    ProgressBar.Position := 0;
    LEDWarning.LedOn := False;
    LEDError.LedOn := False;

    FStartTime := GetTickCount;
  end;

  if OldStat and (not WorkStat[0]) then begin
    OptionsMgr.LogManager.Add(
      Format(rsTimeToSearch, [TimToStr(GetTickCount - FStartTime)]), lpTime);

    If AutoStop then ButtonClose.Click; 

    DataModuleApplication.SearchTrayIcon.Active := False;
    if Iconize then Application.Restore;
  end;
end;

procedure TFormSearch.PluginsObjectTerminate(Sender: TObject);
begin
  WorkStat[1] := False;
  OptionsMgr.LogManager.Add(
    Format(rsStdBytesRecovery,
           [SizeToStr((FPluginsThread as TPluginsObject).TotalSize)]),
    lpSpaceEarn);
end;

procedure TFormSearch.SearchObjectTerminate(Sender: TObject);
var I            : Integer;
    AllSize      : Int64;
    IsErase      : boolean;
begin
  ModifiedActionList(FFileList, SilentMode);

  AllSize := 0;
  for I := 0 to FFileList.Count - 1 do begin
    Inc(AllSize, TFileInfo(FFileList[I]).FileSize);
    if not OptionsMgr.DebugOptions.NoDelete then begin
      case TFileInfo(FFileList[I]).Action of
        fcaDelete : IsErase := XEraseFile(TFileInfo(FFileList[I]).FileName);
        fcaTrash  : IsErase := XEraseFile(TFileInfo(FFileList[I]).FileName, true);
        else IsErase := false;
      end;
    end else
      IsErase := false;

    if IsErase <> (not FileExists(TFileInfo(FFileList[I]).FileName)) then begin
      OptionsMgr.LogManager.Add(TFileInfo(FFileList[I]).FileName, lpError);
    end;

    if not IsErase then begin
      OptionsMgr.LogManager.Add(TFileInfo(FFileList[I]).FileName, lpWarning);
      Dec(AllSize, TFileInfo(FFileList[I]).FileSize);
    end else begin
      OptionsMgr.LogManager.Add(TFileInfo(FFileList[I]).FileName, lpDeletedFile);
    end;
  end;

  OptionsMgr.LogManager.Add(
    Format(rsAdvBytesRecovery, [SizeToStr(AllSize)]), lpSpaceEarn);

  FreeAndNil(FFileList);

  WorkStat[2] := False;
end;

procedure TFormSearch.ActivateSignal(Sender: TObject);
begin
  Application.BringToFront;
end;

procedure TFormSearch.ButtonUpdateClick(Sender: TObject);
begin
  ShellExecute(Handle, nil, 'tilsupdt.exe', 'xdelwin', nil, SW_SHOW);
end;

function TFormSearch.getAutoStop: boolean;
begin
  Result := FAutoStart and FAutoStop;
end;

function TFormSearch.getIconize: boolean;
begin
  Result := FIconize or (Assigned(FOptionsMgr) and FOptionsMgr.Global.Minimize);
end;

end.
