unit SearchObjectThread;

interface

uses
  Classes, Windows, Contnrs, OptionsManager, LogManager;

type
  TFileInfo = class
    FileName: string;
    FileAttr: string;
    FileSize: Int64;
    Action  : TAction;
    Ask     : boolean;
  end;

  TSearchObject = class(TThread)
  private
    FLastCount: LongWord;

    FLine: string;
    FLinePriority: TLinePriority;

    FDirectoryCount,
    FFilesCount,
    FFindedCount: Integer;

    FFileList: TObjectList;

    procedure AddLogLine;
    procedure Counts;

    procedure LogLine(Text: string; Prio: TLinePriority);
    procedure SetName;
    function GetOptions: TOptionsManager;
  protected
    procedure RecurseSearch(Path: String);

    procedure Execute; override;
    property OptionsMgr: TOptionsManager read GetOptions;
  public
    constructor Create(FileList: TObjectList);
  end;

implementation

uses SysUtils, SearchObject, SearchForm, FileTools, resources;

type
  TThreadNameInfo = record
    FType: LongWord;     // doit tre 0x1000
    FName: PChar;        // pointeur sur le nom (dans l'espace d'adresse de l'utilisateur)
    FThreadID: LongWord; // ID de thread (-1=thread de l'appelant)
    FFlags: LongWord;    // rserv pour une future utilisation, doit tre zro
  end;

{ TSearchObject }

procedure TSearchObject.SetName;
var
  ThreadNameInfo: TThreadNameInfo;
begin
  ThreadNameInfo.FType := $1000;
  ThreadNameInfo.FName := 'Search Object Thread';
  ThreadNameInfo.FThreadID := $FFFFFFFF;
  ThreadNameInfo.FFlags := 0;

  try
    RaiseException( $406D1388, 0, sizeof(ThreadNameInfo) div sizeof(LongWord), @ThreadNameInfo );
  except
  end;
end;

procedure TSearchObject.Execute;
var StartDirectory: TStringList;
    I             : Integer;
begin
  SetName;
  LogLine('Starting second step of analyse', lpDebug);

  StartDirectory := TStringList.Create;
  try
    LogLine('Search of base directory', lpDebug);
    OptionsMgr.PersonalSearch.DriveList.BaseDirectoryTo(StartDirectory);
    for I := 0 to StartDirectory.Count - 1 do begin
      LogLine(Format('Analyse of %s ...', [StartDirectory[I]]), lpDebug);
      RecurseSearch(StartDirectory[I]);
      if Terminated then
        break;
    end;
  finally
    StartDirectory.Free;
  end;
  LogLine('Stopping second step of analyse', lpDebug);
end;

procedure TSearchObject.AddLogLine;
begin
  OptionsMgr.LogManager.Add(FLine, FLinePriority);
end;

procedure TSearchObject.LogLine(Text: string; Prio: TLinePriority);
begin
  FLine := Text;
  FLinePriority := Prio;
  Synchronize(AddLogLine);
end;

constructor TSearchObject.Create(FileList: TObjectList);
begin
  inherited Create(True);
  FreeOnTerminate := True;
  FDirectoryCount := 0;
  FFilesCount     := 0;
  FFindedCount    := 0;
  FFileList       := FileList;
end;

procedure TSearchObject.RecurseSearch(Path: String);
var SRec   : TSearchRec;
    Res, I : Integer;
    Msk    : TStringList;
    Dir    : TDirectory;
    FileObj: TFileInfo;
begin
  if Terminated then Exit;

  Inc(FDirectoryCount);
  Path := IncludeTrailingPathDelimiter(Path);

  Res := FindFirst(Path + '*.*', faDirectory, SRec);
  while Res = 0 do begin
    if (SRec.Name <> '.') and (SRec.Name <> '..') and (SRec.Attr and faDirectory > 0) then begin
      RecurseSearch(Path + SRec.Name);
    end else begin
      Inc(FFilesCount);
    end;
    Res := FindNext(SRec);
  end;
  FindClose(SRec);

  if Terminated then Exit;

  Msk := TStringList.Create;

  Dir := OptionsMgr.PersonalSearch.DriveList.Browse(Path, false);
  if CompareStr(Dir.Path, Path) = 0 then
    Dir.Masques(Msk)
  else
    Dir.MasquesRecursif(Msk);

  for I := 0 to Msk.Count - 1 do begin
    Res := FindFirst(Path + Msk[I], faArchive or faReadOnly or faHidden or faSysFile, SRec);
    while Res = 0 do begin
      Inc(FFindedCount);

      FileObj := TFileInfo.Create;
      FileObj.FileName := Path + SRec.Name;
      FileObj.FileAttr := FileAttribue(SRec);
      FileObj.FileSize := SizeOfFile(FileObj.FileName);
      FFileList.Add(FileObj);

      Res := FindNext(SRec);
    end;
    FindClose(SRec);
  end;
  Msk.Free;

  if GetTickCount - FLastCount > 500 then begin
    Synchronize(Counts);
    FLastCount := GetTickCount;
  end;
end;

procedure TSearchObject.Counts;
begin
  FormSearch.LabelStatus.Caption := Format(
    rsNumberOfFilesFinded, [FFilesCount, FFindedCount, FDirectoryCount]);
end;

function TSearchObject.GetOptions: TOptionsManager;
begin
  result := FormSearch.OptionsMgr;
end;

end.
