library Systeme;

{$E xdl}

{$R *.res}

uses
  Windows,
  SysUtils,
  WinInfos,
  FileTools,
  tShellAPI,
  Registry,
  PluginsTypes in 'PluginsTypes.pas';

var
  PrefetchDir: PChar = nil;
  DumpDir    : PChar = nil;

procedure GetPrefetchDir(out Directory: PChar; out Size: Integer); stdcall;
var Chaine: string;
begin
  if not Assigned(PrefetchDir) then begin
    Chaine := IncludeTrailingPathDelimiter(GetWindowsDir()) + 'Prefetch';

    GetMem(PrefetchDir, Length(Chaine) + 1);
    StrPCopy(PrefetchDir, Chaine)
  end;

  Directory := PrefetchDir;
  Size := SizeOfDir(Directory);
end;

function CleanPrefetchDir(): Integer; stdcall;
var Size1, Size2: Integer;
    P: PChar;
begin
  GetPrefetchDir(P, Size1);
  XEraseRecurseDir(P);
  ForceDirectories(P);
  Size2 := SizeOfDir(P);
  if Size2 >= 0 then begin
    result := Size1 - Size2
  end else
    result := -1;
end;

procedure GetDumpDir(out Directory: PChar; out Size: Integer); stdcall;
var Chaine: string;
begin
  if not Assigned(DumpDir) then begin
    Chaine := IncludeTrailingPathDelimiter(GetWindowsDir()) + 'Minidump';

    GetMem(DumpDir, Length(Chaine) + 1);
    StrPCopy(DumpDir, Chaine);
  end;

  Directory := DumpDir;
  Size := SizeOfDir(Directory);
end;

function CleanDumpDir(): Integer; stdcall;
var Size1, Size2: Integer;
    P: PChar;
begin
  GetDumpDir(P, Size1);
  XEraseRecurseDir(P);
  ForceDirectories(P);
  Size2 := SizeOfDir(P);
  if Size2 >= 0 then begin
    result := Size1 - Size2
  end else
    result := -1;
end;

var
  AppLogDir: PChar = nil;
  Registre: TRegistry;

procedure GetAppDir(out Directory: PChar; out Size: Integer); stdcall;
var Chaine: string;
begin
  if not Assigned(AppLogDir) then begin
    Chaine := IncludeTrailingPathDelimiter(GetWindowsDir()) + 'AppLog';

    GetMem(DumpDir, Length(Chaine) + 1);
    StrPCopy(DumpDir, Chaine);
  end;

  Directory := DumpDir;
  Size := SizeOfDir(Directory);
end;

function CleanAppDir(): Integer; stdcall;
var Size1, Size2: Integer;
    P: PChar;
begin
  GetAppDir(P, Size1);
  XEraseRecurseDir(P);
  ForceDirectories(P);
  Size2 := SizeOfDir(P);
  if Size2 >= 0 then begin
    result := Size1 - Size2
  end else
    result := -1;
end;

const
  RegPath = 'Software\Microsoft\Windows\CurrentVersion\Exporer\';

function CleanDocument(): Integer; stdcall;
begin
  Registre.DeleteKey(RegPath + 'Doc Find Spec MRU');
  Registre.CreateKey(RegPath + 'Doc Find Spec MRU');
  result := -1;
end;

function CleanComputer(): Integer; stdcall;
begin
  Registre.DeleteKey(RegPath + 'FindComputerMRU');
  Registre.CreateKey(RegPath + 'FindComputerMRU');
  result := -1;
end;

const
  Plugins9x: array[0..2] of TPlugin =
  ((pVersion: 0;
    pIdentificateur: 'D4CA9E-03090632-71269701';
    pDescription: 'Journal des applications (AppLog)';
    pLibType: pltSystem;
    pIsCheckDefault: false;
    pDirectoryFunc: GetAppDir;
    pCleanFunc: CleanAppDir),
   (pVersion: 0;
    pIdentificateur: '556ABF-03090632-C261D610';
    pDescription: 'Liste des documents recherchs';
    pLibType: pltUser;
    pIsCheckDefault: true;
    pDirectoryFunc: nil;
    pCleanFunc: CleanDocument),
   (pVersion: 0;
    pIdentificateur: 'C8A870-03090632-5B7B62C2';
    pDescription: 'Liste des ordinateurs recherchs';
    pLibType: pltUser;
    pIsCheckDefault: true;
    pDirectoryFunc: nil;
    pCleanFunc: CleanComputer));

  PluginsNT: array[0..1] of TPlugin =
  ((pVersion: 0;
    pIdentificateur: 'B93EF7-03090632-C2B287C3';
    pDescription: 'Prchargement des logiciels (Prefetch)';
    pLibType: pltSystem;
    pIsCheckDefault: false;
    pDirectoryFunc: GetPrefetchDir;
    pCleanFunc: CleanPrefetchDir),
   (pVersion: 0;
    pIdentificateur: 'E6CCB2-03090632-0C1E5D8D';
    pDescription: 'Dump de la mmoire (MiniDump)';
    pLibType: pltSystem;
    pIsCheckDefault: true;
    pDirectoryFunc: GetDumpDir;
    pCleanFunc: CleanDumpDir));

function GetCountPlugins: Integer; stdcall;
begin
  if Win32Platform = VER_PLATFORM_WIN32_NT then
    result := High(PluginsNT) - Low(PluginsNT) + 1
  else
    result := High(Plugins9x) - Low(Plugins9x) - 1
end;

function GetPlugin(const Index: Integer): PPlugin; stdcall;
begin
  if Win32Platform = VER_PLATFORM_WIN32_NT then
    result := @PluginsNT[Index]
  else
    result := @Plugins9x[Index];
end;

exports
  GetCountPlugins,
  GetPlugin;

begin
  Registre := TRegistry.Create;
end.
