library tmp_trash;

{$E xdl}

{$R *.res}

uses
  Windows,
  SysUtils,
  WinInfos,
  FileTools,
  tShellAPI,
  PluginsTypes in 'PluginsTypes.pas';

var
  SystemTemp: PChar = nil;
  UserTemp: PChar = nil;

procedure GetSystemTempory(out Directory: PChar; out Size: Integer); stdcall;
var Chaine: string;
begin
  if not Assigned(SystemTemp) then begin
    if Win32Platform = VER_PLATFORM_WIN32_NT then
      Chaine := IncludeTrailingPathDelimiter(GetWindowsDir()) + 'TEMP'
    else
      Chaine := GetTempDir;

    GetMem(SystemTemp, Length(Chaine) + 1);
    StrPCopy(SystemTemp, Chaine)
  end;

  Directory := SystemTemp;
  Size := SizeOfDir(Directory);
end;

function CleanSystemTempory(): Integer; stdcall;
var Size1, Size2: Integer;
    P: PChar;
begin
  GetSystemTempory(P, Size1);
  XEraseRecurseDir(P);
  ForceDirectories(P);
  Size2 := SizeOfDir(P);
  if Size2 >= 0 then begin
    result := Size1 - Size2
  end else
    result := -1;
end;

procedure GetUserTempory(out Directory: PChar; out Size: Integer); stdcall;
var Chaine: string;
begin
  if not Assigned(UserTemp) then begin
    Chaine := GetTempDir;
    GetMem(UserTemp, Length(Chaine) + 1);
    StrPCopy(UserTemp, Chaine)
  end;

  Directory := UserTemp;
  Size := SizeOfDir(Directory);
end;

function CleanUserTempory(): Integer; stdcall;
var Size1, Size2: Integer;
    P: PChar;
begin
  GetUserTempory(P, Size1);
  XEraseRecurseDir(P);
  ForceDirectories(P);
  Size2 := SizeOfDir(P);
  if Size2 >= 0 then begin
    result := Size1 - Size2
  end else
    result := -1;
end;

function CleanTrash(): Integer; stdcall;
begin
  ShellEmptyRecycleBin;
  result := -1;
end;

const
  (* Plugins pour tout system d'exploitation *)
  Plugins: array[0..1] of TPlugin =
  ((pVersion: 0;
    pIdentificateur: '922FC1-03090632-8363170C';
    pDescription: 'Corbeille';
    pLibType: pltSystem;
    pIsCheckDefault: true;
    pDirectoryFunc: nil;
    pCleanFunc: CleanTrash),
   (pVersion: 0;
    pIdentificateur: 'D75A31-03090632-0A5B6CE5';
    pDescription: 'Dossier temporaire';
    pLibType: pltSystem;
    pIsCheckDefault: true;
    pDirectoryFunc: GetSystemTempory;
    pCleanFunc: CleanSystemTempory));
  (* Plugins rservs au system NT *)
  PluginsNT: array[0..0] of TPlugin =
  ((pVersion: 0;
    pIdentificateur: '6BC02B-03090632-B3435569';
    pDescription: 'Dossier temporaire';
    pLibType: pltUser;
    pIsCheckDefault: true;
    pDirectoryFunc: GetUserTempory;
    pCleanFunc: CleanUserTempory));

(* Fonction pour rcuprer les Plugins *)

function GetCountPlugins: Integer; stdcall;
begin
  result := High(Plugins) - Low(Plugins) + 1;
  if Win32Platform = VER_PLATFORM_WIN32_NT then
    Inc(result, High(PluginsNT) - Low(PluginsNT) + 1);
end;

function GetPlugin(const Index: Integer): PPlugin; stdcall;
begin
  if Index <= High(Plugins) then
    result := @Plugins[Index]
  else
    result := @PluginsNT[Index - High(Plugins) - 1];
end;

exports
  GetCountPlugins,
  GetPlugin;

(*************** Initialisation/Nettoyage de la librairie *********************)

var
  ExitProc: TProcedure;

procedure FinalizeLib;
begin
  FreeMem(SystemTemp); SystemTemp := nil;
  FreeMem(UserTemp); UserTemp := nil;

  ExitProc;
end;

begin
  ExitProc := ExitProcessProc;
  ExitProcessProc := FinalizeLib;
end.
